<?php
/**
 * Created by PhpStorm.
 * User: phillipesilva
 * Date: 06/08/14
 * Time: 13:03
 */

namespace Folha\Logic\SituacaoFrequencia;

use Folha\Entities\PtoAssocsitufreq;
use Folha\Entities\PtoSitufrequencia;
use Geral\Util\NovoCodigo;
use Setforms2\Shared\Registry;

class AssociacaoFrequencia {
    public static function insertOrUpdateAssociacaoSituacao($dados)
    {
        $entityManager = Registry::getEntityManager();
        $db = $entityManager->getConnection();
        $db->beginTransaction();

        try {
            $nrOrgReturn = $dados['NRORG'];

            //Se não existir existir Organização de Trabalho significa que está alterando uma padrão.
            if($dados['NRORGTRAB'] == '' || is_null($dados['NRORGTRAB'])) {
                $dados['NRASSOCSITUFREQ'] = NovoCodigo::geraCodigo($dados['NRORG'], 'PTO_ASSOCSITUFREQ', 1);
                $assSituFreq = new PtoAssocsitufreq();
                $assSituFreq->setDtinclusao($dados['DATAATUAL']);
                $assSituFreq->setNrorginclusao($dados['NRORG']);
                $assSituFreq->setCdoperinclusao($dados['CDOPERADOR']);

                self::setColumsAssociacao($assSituFreq, $dados);
            } else {
                //Caso esteja alterando uma de trabalho mas os dados sejam os mesmos de uma padrão, exclui a de trabalho e mantém a padrão.
                $assSituPadr = PtoAssocsitufreq::findOneByNrcalculositufreqAndNrsitufrequenciaAndNrorg($dados['NRCALCULOSITUFREQ'], $dados['NRSITUFREQUENCIA'], $dados['NRORGPADRAO']);

                if(is_object($assSituPadr)) {
                    self::deleteAssociacaoFrequencia($dados['NRASSOCSITUFREQ'], $dados['NRORG']);

                    $nrOrgReturn = $dados['NRORGPADRAO'];
                } else {
                    //Em outros casos, apenas altera o necessário.
                    $assSituFreq = PtoAssocsitufreq::findOneByNrassocsitufreqAndNrorg($dados['NRASSOCSITUFREQ'], $dados['NRORG']);

                    self::setColumsAssociacao($assSituFreq, $dados);
                }
            }

            $entityManager->flush();
            $db->commit();

            return array($dados['NRASSOCSITUFREQ'], $nrOrgReturn);
        } catch (\Exception $e) {
            $db->rollback();
            throw $e;
        }
    }

    private static function setColumsAssociacao(PtoAssocsitufreq $assSituFreq, $dados)
    {
        $assSituFreq->setNrsitufrequencia($dados['NRSITUFREQUENCIA']);
        $assSituFreq->setNrassocsitufreq($dados['NRASSOCSITUFREQ']);
        $assSituFreq->setNrcalculositufreq($dados['NRCALCULOSITUFREQ']);
        $assSituFreq->setNrorg($dados['NRORG']);
        $assSituFreq->setIdativo($dados['IDATIVO']);
        $assSituFreq->setDtultatu($dados['DATAATUAL']);
        $assSituFreq->setCdoperultatu($dados['CDOPERADOR']);
        $assSituFreq->setNrorgultatu($dados['NRORG']);
        $assSituFreq->persist();
    }

    public static function deleteAssociacaoFrequencia($nrAssoc, $nrOrg)
    {
        $entityManager = Registry::getEntityManager();
        $db = $entityManager->getConnection();
        $db->beginTransaction();

        try {
            $assSituFreq = PtoAssocsitufreq::findOneByNrassocsitufreqAndNrorg($nrAssoc, $nrOrg);
            $assSituPadr = PtoAssocsitufreq::findOneByNrcalculositufreqAndNrorg($assSituFreq->getNrcalculositufreq(),
                                                                                \FPA::getNrorgPadrao());

            $nrAssocPadr = $nrAssocPadr = $assSituPadr->getNrassocsitufreq();
            $nrSituPadr  = $assSituPadr->getNrsitufrequencia();

            $situFreq    = PtoSitufrequencia::findOneByNrsitufrequenciaAndNrorg($nrSituPadr, \FPA::getNrorgPadrao());
            $dsSituPadr  = $situFreq->getDssitufrequencia();

            $arrayReturn = array($nrAssocPadr, $nrSituPadr, $dsSituPadr);

            if(is_object($assSituFreq)) {
                $assSituFreq->delete();
            }

            $entityManager->flush();
            $db->commit();

            return $arrayReturn;
        } catch (\Exception $e) {
            $db->rollback();
            throw $e;
        }
    }

    public static function returnExistsAssociacaoPadrao($nrCalculo, $nrOrgPadrao)
    {
        $assSituFreq = PtoAssocsitufreq::findOneByNrcalculositufreqAndNrorg($nrCalculo, $nrOrgPadrao);

        if(is_object($assSituFreq)) {
            return true;
        }

        return false;
    }
} 