<?php

namespace Planejamento\Logic\Cardapio;


use Geral\Util\Ambiente;
use Geral\Util\DateUtil;
use Planejamento\Entities\Calencard;

class CalendarioCardapio {

    const ANO = 'ANO';
    const WINDOW = 'win_pla07300_000';

    /**
     * Aplica as Regras de Negócio e efetiva o save dos registros.
     *
     * @param Array $row row
     *
     * @return null
     */
    public static function customSave($row) {
        try {
            $nrorg = $row['NRORG'];
            $cdfilial = $row['CDFILIAL'];
            $dtmescalencard  = $row['DTMESCALENCARD'];
            $dtprevlibecard  = $row['DTPREVLIBECARD'];
            if (empty($dtprevlibecard)) {
                tk_abort(tk_get_message_by_name('msg_pla07300_previsaoLiberacao'));
            }
            $dtprevlibecard  = explode(' ', $dtprevlibecard);
            $dtprevlibecard  = DateUtil::getDataDeString(
                $dtprevlibecard[0], DateUtil::FORMATO_BRASILEIRO, true
            );
            $dtlimaprovfili  = $row['DTLIMAPROVFILI'];
            if (empty($dtlimaprovfili)) {
                tk_abort(tk_get_message_by_name('msg_pla07300_LimAprovFilial'));
            }
            $dtlimaprovfili  = explode(' ', $dtlimaprovfili);
            $dtlimaprovfili  = DateUtil::getDataDeString(
                $dtlimaprovfili[0], DateUtil::FORMATO_BRASILEIRO, true
            );
            $dtlimaprovmatr  = $row['DTLIMAPROVMATR'];
            if (empty($dtlimaprovmatr)) {
                tk_abort(tk_get_message_by_name('msg_pla07300_LimAprovMatriz'));
            }
            $dtlimaprovmatr  = explode(' ', $dtlimaprovmatr);
            $dtlimaprovmatr  = DateUtil::getDataDeString(
                $dtlimaprovmatr[0], DateUtil::FORMATO_BRASILEIRO, true
            );
            $dtbasconcusplan = $row['DTBASCONCUSPLAN'];
            if (empty($dtbasconcusplan) === false) {
                $dtbasconcusplan  = explode(' ', $dtbasconcusplan);
                $dtbasconcusplan = DateUtil::getDataDeString(
                    $dtbasconcusplan[0], DateUtil::FORMATO_BRASILEIRO, true
                );
            }
            $qtdiaproraprov  = $row['QTDIAPRORAPROV'];
            if (empty($qtdiaproraprov) === true) {
                $qtdiaproraprov = 0;
            }
            //$idativo = $row['IDATIVO'];
            $dtmescalencard = explode(' ', $dtmescalencard);
            $dtmescalencard = $dtmescalencard[0];
            $calencard = Calencard::busca($cdfilial, $dtmescalencard, $nrorg);
            if (empty($calencard)) {
                $row = self::setaFields($row);
                $nrorg = $row['NRORG'];
                $cdfilial = $row['CDFILIAL'];
                $dtmescalencard = $row['DTMESCALENCARD'];
                Calencard::insere(
                    $cdfilial, $dtmescalencard, $nrorg, $dtprevlibecard,
                    $dtlimaprovfili, $dtlimaprovmatr, $dtbasconcusplan,
                    $qtdiaproraprov
                );
            } else {
                Calencard::update(
                    $calencard, $dtprevlibecard, $dtlimaprovfili, $dtlimaprovmatr,
                    $dtbasconcusplan, $qtdiaproraprov
                );
            }
            tk_reload_data_with_filter();
        } catch (\Exception $e) {
            tk_warning($e->getMessage());
            return;
        }
    }

    /**
     * Função que seta os valores dos campos que estão NULL no banco.
     *
     * @param Array $row row
     *
     * @return mixed
     */
    public static function setaFields($row)
    {
        $cdfilial = tk_get_context_vars('CDFILIAL', self::WINDOW);
        $row['CDFILIAL'] = $cdfilial;

        $mes = explode(" ", $row['MES']);
        $ano = tk_get_context_vars(self::ANO, self::WINDOW);
        $dtmes = "01/" . $mes[0] . "/" . $ano;
        $dtmes = DateUtil::getDataDeString(
            $dtmes, DateUtil::FORMATO_BRASILEIRO, true
        );
        $row['DTMESCALENCARD'] = $dtmes;

        $nrorg = Ambiente::getNrorg();
        $row['NRORG'] = $nrorg;
        //$row['IDATIVO'] = 'S';
        return $row;
    }
}